@@ -265,7 +265,7 @@ fn run() -> Result<(), Error> {
         run_list()
     } else if let Some(shell) = opt.completion {
         //Opt::clap().gen_completions("procs", shell, "./");
-        clap_complete::generate_to(shell, &mut Opt::into_app(), "procs", "./")?;
+        clap_complete::generate_to(shell, &mut Opt::command(), "procs", "./")?;
         let path = match shell {
             Shell::Bash => "./procs.bash",
             Shell::Elvish => "./procs.elv",
@@ -275,11 +275,11 @@ fn run() -> Result<(), Error> {
             x => return Err(anyhow!("unknown shell type: {}", x)),
         };
         println!("completion file is generated: {}", path);
-        return Ok(());
+        Ok(())
     } else if let Some(shell) = opt.completion_out {
         //Opt::clap().gen_completions_to("procs", shell, &mut stdout());
-        clap_complete::generate(shell, &mut Opt::into_app(), "procs", &mut stdout());
-        return Ok(());
+        clap_complete::generate(shell, &mut Opt::command(), "procs", &mut stdout());
+        Ok(())
     } else {
         let config = get_config()?;
         if opt.watch_mode {
@@ -373,7 +373,7 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
     }
@@ -385,39 +385,39 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "root"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "1"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--or", "root", "1"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--and", "root", "1"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--nor", "root", "1"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--nand", "root", "1"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         config.search.nonnumeric_search = ConfigSearchKind::Exact;
         config.search.numeric_search = ConfigSearchKind::Partial;
         let args = vec!["procs", "root", "1"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
     }
@@ -441,7 +441,7 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         config.pager.mode = ConfigPagerMode::Disable;
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
@@ -454,7 +454,7 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "--insert", "ppid"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
     }
@@ -466,12 +466,12 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "--sorta", "cpu"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--sortd", "cpu"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
     }
@@ -483,7 +483,7 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "--tree"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
     }
@@ -498,7 +498,7 @@ mod tests {
         let _udp = std::net::UdpSocket::bind("127.0.0.1:10000");
 
         let args = vec!["procs"];
-        let opt = Opt::from_iter(args.iter());
+        let opt = Opt::parse_from(args.iter());
         let ret = run_default(&opt, &config);
         assert!(ret.is_ok());
     }
