@@ -2,6 +2,7 @@ use crate::column::Column;
 use crate::columns::{ConfigColumnKind, KIND_LIST};
 use crate::config::{Config, ConfigColumnAlign, ConfigSearchLogic, ConfigTheme};
 use crate::Opt;
+use atty::Stream;
 use byte_unit::Byte;
 use std::borrow::Cow;
 use std::time::Duration;
@@ -161,7 +162,7 @@ pub fn truncate(s: &'_ str, width: usize) -> Cow<'_, str> {
 
 pub fn find_column_kind(pat: &str) -> Option<ConfigColumnKind> {
     for (k, (v, _)) in KIND_LIST.iter() {
-        if v.to_lowercase().find(&pat.to_lowercase()).is_some() {
+        if v.to_lowercase().contains(&pat.to_lowercase()) {
             return Some(k.clone());
         }
     }
@@ -222,9 +223,9 @@ pub fn bytify(x: u64) -> String {
     let byte = Byte::from_bytes(x as u128);
     let byte = byte.get_appropriate_unit(true);
     byte.format(3)
-        .replace(" ", "")
-        .replace("B", "")
-        .replace("i", "")
+        .replace(' ', "")
+        .replace('B', "")
+        .replace('i', "")
 }
 
 pub fn lap(instant: &mut Instant, msg: &str) {
@@ -233,7 +234,7 @@ pub fn lap(instant: &mut Instant, msg: &str) {
         "{} [{}.{:03}s]",
         msg,
         period.as_secs(),
-        period.subsec_nanos() / 1000000
+        period.subsec_millis()
     );
     instant.clone_from(&Instant::now());
 }
@@ -250,8 +251,18 @@ pub fn get_theme(opt: &Opt, config: &Config) -> ConfigTheme {
     };
     match theme {
         ConfigTheme::Auto => {
-            if console::user_attended() {
-                let timeout = Duration::from_millis(100);
+            if atty::is(Stream::Stdout) && atty::is(Stream::Stderr) && atty::is(Stream::Stdin) {
+                let minimum_timeout = Duration::from_millis(100);
+                let timeout = if let Ok(latency) = termbg::latency(Duration::from_millis(10000)) {
+                    if latency * 2 > minimum_timeout {
+                        latency * 2
+                    } else {
+                        minimum_timeout
+                    }
+                } else {
+                    minimum_timeout
+                };
+
                 if let Ok(theme) = termbg::theme(timeout) {
                     match theme {
                         termbg::Theme::Dark => ConfigTheme::Dark,
